create or replace function calculate(device varchar) returns void as $$
begin
	insert into summary 
	select * from (
			(select 
			(case when t1.date is null then t2.date else t1.date end) as date,
			(case when t1.dst_card is null then t2.src_card else t1.dst_card end) as card,
			(case when t1.dst_ip is null then t2.src_ip else t1.dst_ip end) as ip,
			incoming_allowed, incoming_rejected, outgoing_allowed, outgoing_rejected
			from 
				(select date_trunc('day', timestamp) as date, dst_card, dst_ip,
				sum(case when prefix='allow' then bytes else 0 end) as incoming_allowed,
				sum(case when prefix='drop' then bytes else 0 end) as incoming_rejected
				from transfer 
				where src_card=device and dst_card<>device and processed='false'
				group by 1, 2, 3) t1
			full join
				(select date_trunc('day', timestamp) as date, src_card, src_ip,
				sum(case when prefix='allow' then bytes else 0 end) as outgoing_allowed,
				sum(case when prefix='drop' then bytes else 0 end) as outgoing_rejected
				from transfer 
				where dst_card=device and src_card<>device and processed='false'
				group by 1, 2, 3) t2
			on t1.date = t2.date and t1.dst_card=t2.src_card and t1.dst_ip=t2.src_ip)
		union
			(select date_trunc('day', timestamp) as date, 'same' as card, dst_ip as ip,
			sum(case when prefix='allow' then bytes else 0 end) as incoming_allowed,
			sum(case when prefix='drop' then bytes else 0 end) as incoming_rejected,
			0, 0
			from transfer
			where src_card=device and dst_card=device and processed='false'
			group by 1, 2, 3)
	) as processing;
	
	update summary set incoming_allowed = 0 where incoming_allowed is null;
	update summary set incoming_rejected = 0 where incoming_rejected is null;
	update summary set outgoing_allowed = 0 where outgoing_allowed is null;
	update summary set outgoing_rejected = 0 where outgoing_rejected is null;
	
	delete from transfer where extract('day' from (now() - transfer.timestamp))>7;
	update transfer set processed='true' where processed='false';
end;
$$ language plpgsql;
